==> haskell-constraints-extras-0.4.0.1-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-5hgP233GXiX7RcgsXo3Mqr
key:                  constraints-extras-0.4.0.1-5hgP233GXiX7RcgsXo3Mqr
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  969c5e6c8c568aee066513c966d19217
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-5hgP233GXiX7RcgsXo3Mqr
depends:
    base-4.17.2.1 constraints-0.13.4-KHyYL1w2thJBMQRywCPjl1
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-extras-0.4.0.1-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-constraints-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 constraints-extras
version:              0.4.0.1
visibility:           public
id:                   constraints-extras-0.4.0.1-1FcYUIUPfJKBqDpa85paAY
key:                  constraints-extras-0.4.0.1-1FcYUIUPfJKBqDpa85paAY
license:              BSD-3-Clause
copyright:            Obsidian Systems LLC
maintainer:           maintainer@obsidian.systems
author:               Cale Gibbard, Ali Abrar
homepage:             https://github.com/obsidiansystems/constraints-extras
synopsis:             Utility package for constraints
description:
    Convenience functions and TH for working with constraints. See <https://github.com/obsidiansystems/constraints-extras/blob/develop/README.md README.md> for example usage.

category:             Constraints
abi:                  00cdb76048763ef2a04ac6199a6c2d62
exposed:              True
exposed-modules:
    Data.Constraint.Compose Data.Constraint.Extras
    Data.Constraint.Extras.TH Data.Constraint.Flip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/constraints-extras-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-constraints-extras
hs-libraries:         HSconstraints-extras-0.4.0.1-1FcYUIUPfJKBqDpa85paAY
depends:
    base-4.17.2.1 constraints-0.14-ptcKLPcBahCGjnsHD0Bcv
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-constraints-extras/html/constraints-extras.haddock

haddock-html:         /usr/share/doc/haskell-constraints-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
